@@ -2,7 +2,8 @@ from decimal import Decimal
 from django.conf import settings
 from django.test import TestCase
 
-from exchange_eclairs import RateFetchError, RateFetchClient
+from exchange.exceptions import RateFetchError
+from exchange import RateFetchClient
 
 class RateFetchTests(TestCase):
 	# Tests the RateFetchClient
@@ -41,4 +42,4 @@ class RateFetchTests(TestCase):
 		amount = self.fetcher.exchange_currency(amnt, 'uSd', 'cad')
 		self.assertIsInstance(amount, Decimal)
 
-		self.assertRaises(Exception, lambda: self.fetcher.exchange_currency(amnt, 'bore', 'cad'))
\ No newline at end of file
+		self.assertRaises(Exception, lambda: self.fetcher.exchange_currency(amnt, 'bore', 'cad'))
